@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-03 10:51:08
-# @Last Modified time: 2021-08-05 11:44:44
+# @Last Modified time: 2021-08-29 14:51:13
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
@@ -20,12 +20,14 @@ class SqlParse(object):
 
     def __init__(self, orisql):
         self.orisql = orisql
-        self.reg_behind = r'(?=[,);:\s])'
+        self.reg_behind = r'(?=[,();:\s])'
 
     @property
     def sql(self):
         sql = re.sub('^(--.*?\n){0,}', '', self.orisql.strip() + '\n')
-        return sql.strip()
+        sql = sql.strip()
+        sql = sql if sql and sql.endswith(';') else sql + ';' if sql else ''
+        return sql
 
     @property
     def comment(self):
@@ -36,18 +38,24 @@ class SqlParse(object):
 
     @property
     def action(self):
-        action = self.sql.split(' ')[0]
+        if not self.sql:
+            return 'NoSql'
+
+        splits = self.sql.split(' ')
+        action = splits[0]
+        if splits[1].lower() == 'index':
+            action += splits[1]
         return action.upper()
 
     @property
     def tablename(self):
         sql = self.sql
-        create = re.search(r'table (?:if exists |if not exists )?(.*?)(?:\s|;|$)', sql)
-        update = re.search(r'update (.*?)(?:\s|;|$)', sql)
-        insert = re.search(r'insert into (.*?)(?:\s|;|$)', sql)
-        delete = re.search(r'delete (?:from )?(.*?)(?:\s|;|$)', sql)
-        select = re.search(r'select.*?from (.*?)(?:\s|;|$)', sql, re.S)
-        tablename = create or update or insert or delete or select
+        fromt = re.search(rf'(?<=from )(.*?){self.reg_behind}', sql)
+        createt = re.search(rf'table (?:if exists |if not exists )?(.*?){self.reg_behind}', sql)
+        updatet = re.search(rf'update (.*?){self.reg_behind}', sql)
+        insertt = re.search(rf'insert into (.*?){self.reg_behind}', sql)
+        ont = re.search(rf'(?<=on )(.*?){self.reg_behind}', sql)
+        tablename = fromt or ont or createt or updatet or insertt
         tablename = tablename.group(1) if tablename else sql
         return tablename
 
@@ -56,7 +64,7 @@ class SqlFileParse(object):
 
     def __init__(self, filepath):
         self.filepath = filepath
-        self.reg_behind = r'(?=[,);:\s])'
+        self.reg_behind = r'(?=[,();:\s])'
 
     def get_content(self):
         if not os.path.isfile(self.filepath):
@@ -90,7 +98,7 @@ class SqlFileParse(object):
         }
         content = self.get_content()
         content = re.sub('--.*?\n', '\n', content)  # 去掉注释
-        arguments_infile = re.findall(r'(?<!--)\s+#【arguments】#\n(.*?)#【arguments】#', content, re.S)
+        arguments_infile = re.findall(r'(?<!--)\s*#【arguments】#\s*\n(.*?)#【arguments】#', content, re.S)
         arguments_infile = ';'.join(arguments_infile).replace('\n', ';')
         arguments_infile = [argument.strip() for argument in arguments_infile.split(';') if argument]
         for argument in arguments_infile:
@@ -156,7 +164,7 @@ class SqlFileParse(object):
     def get_filesqls(self, **kwargs):
         sqls = {}
         arguments, content = self.replace_params(**kwargs)
-        sqls_tmp = re.findall(r'(?<!--)\s+###\n(.*?)###', content, re.S)
+        sqls_tmp = re.findall(r'(?<!--)\s*###\s*\n(.*?)###', content, re.S)
         for idx, sql in enumerate(sqls_tmp):
             purpose = re.match('-- *(【.*?】)\n', sql.strip())
             purpose = f"【{idx+1:0>3d}】{purpose.group(1)}" if purpose else f'【{idx+1:0>3d}】【No description】'
